@@ -25,23 +25,6 @@
 #include <gtkosxapplication.h>
 #import <Cocoa/Cocoa.h>
 
-gchar *
-_gspell_osx_get_resource_path (void)
-{
-	gchar *id;
-	gchar *ret = NULL;
-
-	id = gtkosx_application_get_bundle_id ();
-
-	if (id != NULL)
-	{
-		ret = gtkosx_application_get_resource_path ();
-	}
-
-	g_free (id);
-	return ret;
-}
-
 gchar *
 _gspell_osx_get_preferred_spell_language ()
 {
@@ -64,5 +47,3 @@ _gspell_osx_get_preferred_spell_language ()
 	[pool release];
 	return ret;
 }
-
-/* ex:set ts=8 noet: */
