@@ -24,6 +24,8 @@
 
 #include <gspell/gspell-checker.h>
 #include <gspell/gspell-checker-dialog.h>
+#include <gspell/gspell-entry.h>
+#include <gspell/gspell-entry-buffer.h>
 #include <gspell/gspell-language.h>
 #include <gspell/gspell-language-chooser.h>
 #include <gspell/gspell-language-chooser-button.h>
@@ -33,8 +35,8 @@
 #include <gspell/gspell-text-buffer.h>
 #include <gspell/gspell-text-view.h>
 
+#include <gspell/gspell-enum-types.h>
+
 #undef GSPELL_H_INSIDE
 
 #endif /* GSPELL_H */
-
-/* ex:set ts=8 noet: */
